@@ -12,9 +12,30 @@ from typing import Protocol
 from typing import Set
 from typing import Tuple
 from typing import Type
+from typing import TYPE_CHECKING
 
 from geneticengine.core.decorators import get_gengy
 
+if TYPE_CHECKING:
+    from geneticengine.core.representations.tree.utils import GengyList
+    from geneticengine.core.tree import TreeNode
+
+
+def has_annotated_mutation(ty: type[Any]):
+    """Returns whether type has an annotated mutation within metadata."""
+    if hasattr(ty, "__metadata__"):
+        if hasattr(ty.__metadata__[0], "mutate"):
+            return True
+    return False
+
+
+def has_annotated_crossover(ty: type[Any]):
+    """Returns whether type has an annotated crossover within metadata."""
+    if hasattr(ty, "__metadata__"):
+        if hasattr(ty.__metadata__[0], "crossover"):
+            return True
+    return False
+
 
 def is_annotated(ty: type[Any]):
     """Returns whether type is annotated with metadata."""
@@ -75,6 +96,8 @@ def get_arguments(n) -> list[tuple[str, type]]:
             include_extras=True,
         )
         return [(a, args[a]) for a in filter(lambda x: x != "return", args)]
+    elif isinstance(n, GengyList):
+        return [(f"{i}", n.typ) for i in range(len(n))]
     return []
 
 
@@ -85,8 +108,6 @@ def is_abstract(t: type) -> bool:
 
 def is_terminal(t: type, l: set[type]) -> bool:
     """Returns whether a node is a terminal or not, based on the list of non terminals in the grammar"""
-    if isinstance(t, list):
-        return False
     if is_annotated(t):
         return all([is_terminal(inner, l) for inner in get_generic_parameters(t)])
     if not has_arguments(t):
