@@ -49,6 +49,7 @@ class GeneticProgrammingRegressor(BaseEstimator, TransformerMixin):
         - max_depth (int): The maximum depth a tree can have (default = 15).
         - favor_less_deep_trees (bool): If set to True, this gives a tiny penalty to deeper trees to favor simpler trees (default = False).
         - hill_climbing (bool): Allows the user to change the standard mutation operations to the hill-climbing mutation operation, in which an individual is mutated to 5 different new individuals, after which the best is chosen to survive (default = False).
+        - metric (str): Choose the metric used in the fitness function. Currently available: mean square error (mse), and the r2 measure (r2), new once can be requested or easily implemented by the user (default = 'mse').
         -----
         Defaults as given in A Field Guide to GP, p.17, by Poli and Mcphee:
         - probability_mutation (float): probability that an individual is mutated (default = 0.01).
@@ -108,12 +109,7 @@ class GeneticProgrammingRegressor(BaseEstimator, TransformerMixin):
         self.probability_crossover = probability_crossover
         self.timer_stop_criteria = timer_stop_criteria
         self.timer_limit = timer_limit
-        if metric == "r2":
-            self.metric = r2
-            self.minimise = False
-        else:
-            self.metric = mse
-            self.minimise = True
+        self.metric = metric
 
     def fit(self, X, y):
         """
@@ -141,6 +137,13 @@ class GeneticProgrammingRegressor(BaseEstimator, TransformerMixin):
         self.feature_names = feature_names
         self.feature_indices = feature_indices
 
+        if self.metric == "r2":
+            metric = r2
+            minimise = False
+        else:
+            metric = mse
+            minimise = True
+
         def fitness_function(n: Number):
             variables = {}
             for x in feature_names:
@@ -148,7 +151,7 @@ class GeneticProgrammingRegressor(BaseEstimator, TransformerMixin):
                 variables[x] = data[:, i]
             y_pred = n.evaluate(**variables)
 
-            fitness = self.metric(
+            fitness = metric(
                 y_pred,
                 target,
             )
@@ -159,7 +162,7 @@ class GeneticProgrammingRegressor(BaseEstimator, TransformerMixin):
         model = GP(
             grammar=self.grammar,
             evaluation_function=fitness_function,
-            minimize=self.minimise,
+            minimize=minimise,
             representation=self.representation,
             population_size=self.population_size,
             n_elites=self.n_elites,
